==> zio-aws-iotanalytics_2.12-5.17.130.2-sources.jar: zio/aws/iotanalytics/model/SelectAttributesActivity.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.iotanalytics.model.primitives.{AttributeName, ActivityName}
import scala.jdk.CollectionConverters._
final case class SelectAttributesActivity(
    name: ActivityName,
    attributes: Iterable[AttributeName],
    next: Option[ActivityName] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity = {
    import SelectAttributesActivity.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
      .builder()
      .name(ActivityName.unwrap(name): java.lang.String)
      .attributes(attributes.map { item =>
        AttributeName.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(
        next.map(value => ActivityName.unwrap(value): java.lang.String)
      )(_.next)
      .build()
  }
  def asReadOnly: zio.aws.iotanalytics.model.SelectAttributesActivity.ReadOnly =
    zio.aws.iotanalytics.model.SelectAttributesActivity.wrap(buildAwsValue())
}
object SelectAttributesActivity {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.SelectAttributesActivity =
      zio.aws.iotanalytics.model
        .SelectAttributesActivity(name, attributes, next.map(value => value))
    def name: ActivityName
    def attributes: List[AttributeName]
    def next: Option[ActivityName]
    def getName: ZIO[Any, Nothing, ActivityName] = ZIO.succeed(name)
    def getAttributes: ZIO[Any, Nothing, List[AttributeName]] =
      ZIO.succeed(attributes)
    def getNext: ZIO[Any, AwsError, ActivityName] =
      AwsError.unwrapOptionField("next", next)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
  ) extends zio.aws.iotanalytics.model.SelectAttributesActivity.ReadOnly {
    override val name: ActivityName =
      zio.aws.iotanalytics.model.primitives.ActivityName(impl.name())
    override val attributes: List[AttributeName] = impl
      .attributes()
      .asScala
      .map { item =>
        zio.aws.iotanalytics.model.primitives.AttributeName(item)
      }
      .toList
    override val next: Option[ActivityName] = scala
      .Option(impl.next())
      .map(value => zio.aws.iotanalytics.model.primitives.ActivityName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
  ): zio.aws.iotanalytics.model.SelectAttributesActivity.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-iotanalytics_2.12-6.20.115.2-sources.jar: zio/aws/iotanalytics/model/SelectAttributesActivity.scala <==
package zio.aws.iotanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.iotanalytics.model.primitives.{AttributeName, ActivityName}
import scala.jdk.CollectionConverters._
final case class SelectAttributesActivity(
    name: ActivityName,
    attributes: Iterable[AttributeName],
    next: Optional[ActivityName] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity = {
    import SelectAttributesActivity.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
      .builder()
      .name(ActivityName.unwrap(name): java.lang.String)
      .attributes(attributes.map { item =>
        AttributeName.unwrap(item): java.lang.String
      }.asJavaCollection)
      .optionallyWith(
        next.map(value => ActivityName.unwrap(value): java.lang.String)
      )(_.next)
      .build()
  }
  def asReadOnly: zio.aws.iotanalytics.model.SelectAttributesActivity.ReadOnly =
    zio.aws.iotanalytics.model.SelectAttributesActivity.wrap(buildAwsValue())
}
object SelectAttributesActivity {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.iotanalytics.model.SelectAttributesActivity =
      zio.aws.iotanalytics.model
        .SelectAttributesActivity(name, attributes, next.map(value => value))
    def name: ActivityName
    def attributes: List[AttributeName]
    def next: Optional[ActivityName]
    def getName: ZIO[Any, Nothing, ActivityName] = ZIO.succeed(name)
    def getAttributes: ZIO[Any, Nothing, List[AttributeName]] =
      ZIO.succeed(attributes)
    def getNext: ZIO[Any, AwsError, ActivityName] =
      AwsError.unwrapOptionField("next", next)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
  ) extends zio.aws.iotanalytics.model.SelectAttributesActivity.ReadOnly {
    override val name: ActivityName =
      zio.aws.iotanalytics.model.primitives.ActivityName(impl.name())
    override val attributes: List[AttributeName] = impl
      .attributes()
      .asScala
      .map { item =>
        zio.aws.iotanalytics.model.primitives.AttributeName(item)
      }
      .toList
    override val next: Optional[ActivityName] = zio.aws.core.internal
      .optionalFromNullable(impl.next())
      .map(value => zio.aws.iotanalytics.model.primitives.ActivityName(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.iotanalytics.model.SelectAttributesActivity
  ): zio.aws.iotanalytics.model.SelectAttributesActivity.ReadOnly = new Wrapper(
    impl
  )
}
